@@ -1,7 +1,7 @@
-from cubicweb.selectors import implements
+from cubicweb.selectors import is_instance
 from cubicweb.sobjects.notification import ContentAddedView
 
 class TaskAddedView(ContentAddedView):
     """get notified from new tasks"""
-    __select__ = implements('Task')
+    __select__ = is_instance('Task')
     content_attr = 'description'
