@@ -1,6 +1,6 @@
 from yams.buildobjs import (EntityType, RelationDefinition,
                             String, Datetime, RichString)
-
+from yams.constraints import BoundaryConstraint, Attribute
 from cubicweb.schema import WorkflowableEntityType
 
 
@@ -8,9 +8,8 @@ class Task(WorkflowableEntityType):
     """something to do"""
     title  = String(required=True, fulltextindexed=True, maxsize=64)
     description = RichString(fulltextindexed=True)
-
-    start  = Datetime(default='TODAY')
-    stop   = Datetime(default='TODAY')
+    start = Datetime(constraints=[BoundaryConstraint('<=', Attribute('stop'))])
+    stop  = Datetime(constraints=[BoundaryConstraint('>=', Attribute('start'))])
 
 
 class todo_by(RelationDefinition):
