@@ -19,6 +19,7 @@ _pvs = uicfg.primaryview_section
 _pvs.tag_subject_of(('Task', 'todo_by', '*'), 'attributes')
 _pvs.tag_attribute(('Task', 'start'), 'hidden')
 _pvs.tag_attribute(('Task', 'stop'), 'hidden')
+_pvs.tag_attribute(('Task', 'title'), 'hidden') # in title
 
 _abaa = uicfg.actionbox_appearsin_addmenu
 _abaa.tag_object_of(('Task', 'todo_by', 'CWUser'), False)
@@ -37,8 +38,9 @@ class TaskPrimaryView(primary.PrimaryView):
     __select__ = is_instance('Task')
 
     def render_entity_attributes(self, entity):
-        self.w(u'<h2>%s - %s</h2>' % (self._cw.format_date(entity.start),
-                                      self._cw.format_date(entity.stop)))
+        if entity.start:
+            self.w(u'<h2>%s - %s</h2>' % (self._cw.format_date(entity.start),
+                                          self._cw.format_date(entity.stop)))
         super(TaskPrimaryView, self).render_entity_attributes(entity)
 
 
